@@ -13,14 +13,13 @@ def get_pit(pit_name):
 		return None
 
 def create_pit(pit_name, host_string):
-	split_host = host_string.split(':')
-	if len(split_host) < 2:
-		split_host.append(22)
+	(host, ssh_port, mosh_port) = split_host(host_string)
 
 	pit = Pit()
 	pit.name = pit_name
-	pit.host = split_host[0]
-	pit.port = split_host[1]
+	pit.host = host
+	pit.ssh_port = ssh_port
+	pit.mosh_port = mosh_port
 
 	session = get_session()
 	session.add(pit)
@@ -32,12 +31,11 @@ def create_pit(pit_name, host_string):
 def update_pit(pit_name, host_string):
 	pit = get_pit(pit_name)
 
-	split_host = host_string.split(':')
-	if len(split_host) < 2:
-		split_host.append(22)
+	(host, ssh_port, mosh_port) = split_host(host_string)
 
-	pit.host = split_host[0]
-	pit.port = split_host[1]
+	pit.host = host
+	pit.ssh_port = ssh_port
+	pit.mosh_port = mosh_port
 
 	session = get_session()
 	session.add(pit)
@@ -67,4 +65,16 @@ def list_pits():
 
 def pit(pit_name):
 	pit = get_pit(pit_name)
-	return system( "mosh --ssh=\"ssh -p %i\" %s" % (pit.port, pit.host) )
\ No newline at end of file
+	return system( "mosh %s --ssh=\"ssh -p %i\" %s" % ('-p %i' % pit.mosh_port if pit.mosh_port else '', pit.ssh_port, pit.host) )
+
+def split_host(host_string):
+	split = host_string.split(':')
+	if len(split) < 2:
+		split.append(22)
+	if len(split) < 3:
+		split.append(None)
+
+	return (split[0], split[1], split[2])
+
+def migrate():
+	pass
\ No newline at end of file
