@@ -14,7 +14,7 @@ def get_session():
 	Session = sessionmaker(bind=engine)
 	return Session()
 
-class Pit(Base):
+class Pit1(Base):
 	__tablename__ = 'pits'
 
 	id = Column(Integer, primary_key=True)
@@ -25,4 +25,16 @@ class Pit(Base):
 	def __repr__(self):
 		return "%s    %s:%i" % (self.name, self.host, self.port)
 
+class Pit(Base):
+	__tablename__ = 'pits2'
+
+	id = Column(Integer, primary_key=True)
+	name = Column(String)
+	host = Column(String)
+	ssh_port = Column(Integer)
+	mosh_port = Column(Integer)
+
+	def __repr__(self):
+		return "%s    %s:%i%s" % (self.name, self.host, self.ssh_port, ':%i' % self.mosh_port if self.mosh_port else '')
+
 Pit.metadata.create_all(get_engine())
\ No newline at end of file
